"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def generate(
    hub,
    ctx,
    key_id: str,
    encryption_context: Dict = None,
    number_of_bytes: int = None,
    key_spec: str = None,
    grant_tokens: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a unique symmetric data key for client-side encryption. This operation returns a plaintext copy of the data key and a copy that is encrypted under a customer master key (CMK) that you specify. You can use the plaintext key to encrypt your data outside of AWS KMS and store the encrypted data key with the encrypted data.  GenerateDataKey returns a unique data key for each request. The bytes in the plaintext key are not related to the caller or the CMK. To generate a data key, specify the symmetric CMK that will be used to encrypt the data key. You cannot use an asymmetric CMK to generate data keys. To get the type of your CMK, use the DescribeKey operation. You must also specify the length of the data key. Use either the KeySpec or NumberOfBytes parameters (but not both). For 128-bit and 256-bit data keys, use the KeySpec parameter.  To get only an encrypted copy of the data key, use GenerateDataKeyWithoutPlaintext. To generate an asymmetric data key pair, use the GenerateDataKeyPair or GenerateDataKeyPairWithoutPlaintext operation. To get a cryptographically secure random byte string, use GenerateRandom. You can use the optional encryption context to add additional security to the encryption operation. If you specify an EncryptionContext, you must specify the same encryption context (a case-sensitive exact match) when decrypting the encrypted data key. Otherwise, the request to decrypt fails with an InvalidCiphertextException. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  How to use your data key  We recommend that you use the following pattern to encrypt data locally in your application. You can write your own code or use a client-side encryption library, such as the AWS Encryption SDK, the Amazon DynamoDB Encryption Client, or Amazon S3 client-side encryption to do these tasks for you. To encrypt data outside of AWS KMS:   Use the GenerateDataKey operation to get a data key.   Use the plaintext data key (in the Plaintext field of the response) to encrypt your data outside of AWS KMS. Then erase the plaintext data key from memory.   Store the encrypted data key (in the CiphertextBlob field of the response) with the encrypted data.   To decrypt data outside of AWS KMS:   Use the Decrypt operation to decrypt the encrypted data key. The operation returns a plaintext copy of the data key.   Use the plaintext data key to decrypt data outside of AWS KMS, then erase the plaintext data key from memory.    Cross-account use: Yes. To perform this operation with a CMK in a different AWS account, specify the key ARN or alias ARN in the value of the KeyId parameter.  Required permissions: kms:GenerateDataKey (key policy)  Related operations:     Decrypt     Encrypt     GenerateDataKeyPair     GenerateDataKeyPairWithoutPlaintext     GenerateDataKeyWithoutPlaintext

    Args:
        key_id(str): Identifies the symmetric CMK that encrypts the data key. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
        encryption_context(Dict, optional): Specifies the encryption context that will be used when encrypting the data key. An encryption context is a collection of non-secret key-value pairs that represents additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is optional when encrypting with a symmetric CMK, but it is highly recommended. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. Defaults to None.
        number_of_bytes(int, optional): Specifies the length of the data key in bytes. For example, use the value 64 to generate a 512-bit data key (64 bytes is 512 bits). For 128-bit (16-byte) and 256-bit (32-byte) data keys, use the KeySpec parameter. You must specify either the KeySpec or the NumberOfBytes parameter (but not both) in every GenerateDataKey request. Defaults to None.
        key_spec(str, optional): Specifies the length of the data key. Use AES_128 to generate a 128-bit symmetric key, or AES_256 to generate a 256-bit symmetric key. You must specify either the KeySpec or the NumberOfBytes parameter (but not both) in every GenerateDataKey request. Defaults to None.
        grant_tokens(List, optional): A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.data_key.init.generate(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.data_key.init.generate key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="generate_data_key",
        op_kwargs={
            "KeyId": key_id,
            "EncryptionContext": encryption_context,
            "NumberOfBytes": number_of_bytes,
            "KeySpec": key_spec,
            "GrantTokens": grant_tokens,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, backup_vault_name: str, recovery_point_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the recovery point specified by a recovery point ID. If the recovery point ID belongs to a continuous backup, calling this endpoint deletes the existing continuous backup and stops future continuous backup.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.
        recovery_point_arn(str): An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.recovery_point.init.delete(
                ctx, backup_vault_name=value, recovery_point_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.recovery_point.init.delete backup_vault_name=value, recovery_point_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="delete_recovery_point",
        op_kwargs={
            "BackupVaultName": backup_vault_name,
            "RecoveryPointArn": recovery_point_arn,
        },
    )


async def describe(hub, ctx, backup_vault_name: str, recovery_point_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata associated with a recovery point, including ID, status, encryption, and lifecycle.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.
        recovery_point_arn(str): An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.recovery_point.init.describe(
                ctx, backup_vault_name=value, recovery_point_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.recovery_point.init.describe backup_vault_name=value, recovery_point_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="describe_recovery_point",
        op_kwargs={
            "BackupVaultName": backup_vault_name,
            "RecoveryPointArn": recovery_point_arn,
        },
    )


async def disassociate(
    hub, ctx, backup_vault_name: str, recovery_point_arn: str
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified continuous backup recovery point from AWS Backup and releases control of that continuous backup to the source service, such as Amazon RDS. The source service will continue to create and retain continuous backups using the lifecycle that you specified in your original backup plan. Does not support snapshot backup recovery points.

    Args:
        backup_vault_name(str): The unique name of an AWS Backup vault. Required.
        recovery_point_arn(str): An Amazon Resource Name (ARN) that uniquely identifies an AWS Backup recovery point. Required.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.recovery_point.init.disassociate(
                ctx, backup_vault_name=value, recovery_point_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.recovery_point.init.disassociate backup_vault_name=value, recovery_point_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="disassociate_recovery_point",
        op_kwargs={
            "BackupVaultName": backup_vault_name,
            "RecoveryPointArn": recovery_point_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(
    hub, ctx, quota_code: str, service_code: str, aws_region: str, desired_value: float
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a quota increase request to your quota request template.

    Args:
        quota_code(str): The quota identifier.
        service_code(str): The service identifier.
        aws_region(str): The AWS Region.
        desired_value(float): The new, increased value for the quota.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.service.quota.increase.request.into_template.put(
                ctx, quota_code=value, service_code=value, aws_region=value, desired_value=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.service.quota.increase.request.into_template.put quota_code=value, service_code=value, aws_region=value, desired_value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="put_service_quota_increase_request_into_template",
        op_kwargs={
            "QuotaCode": quota_code,
            "ServiceCode": service_code,
            "AwsRegion": aws_region,
            "DesiredValue": desired_value,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    relational_database_name: str,
    log_stream_name: str,
    start_time: str = None,
    end_time: str = None,
    start_from_head: bool = None,
    page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of log events for a database in Amazon Lightsail.

    Args:
        relational_database_name(str): The name of your database for which to get log events.
        log_stream_name(str): The name of the log stream. Use the get relational database log streams operation to get a list of available log streams.
        start_time(str, optional): The start of the time interval from which to get log events. Constraints:   Specified in Coordinated Universal Time (UTC).   Specified in the Unix time format. For example, if you wish to use a start time of October 1, 2018, at 8 PM UTC, then you input 1538424000 as the start time.  . Defaults to None.
        end_time(str, optional): The end of the time interval from which to get log events. Constraints:   Specified in Coordinated Universal Time (UTC).   Specified in the Unix time format. For example, if you wish to use an end time of October 1, 2018, at 8 PM UTC, then you input 1538424000 as the end time.  . Defaults to None.
        start_from_head(bool, optional): Parameter to specify if the log should start from head or tail. If true is specified, the log event starts from the head of the log. If false is specified, the log event starts from the tail of the log.  For PostgreSQL, the default value of false is the only option available. . Defaults to None.
        page_token(str, optional): The token to advance to the next or previous page of results from your request. To get a page token, perform an initial GetRelationalDatabaseLogEvents request. If your results are paginated, the response will return a next forward token and/or next backward token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.log.event.get_all(
                ctx, relational_database_name=value, log_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.log.event.get_all relational_database_name=value, log_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database_log_events",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "logStreamName": log_stream_name,
            "startTime": start_time,
            "endTime": end_time,
            "startFromHead": start_from_head,
            "pageToken": page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, log_bucket: str) -> Dict:
    r"""
    **Autogenerated function**

    Authorizes the Shield Response Team (SRT) to access the specified Amazon S3 bucket containing log data such as Application Load Balancer access logs, CloudFront logs, or logs from third party sources. You can associate up to 10 Amazon S3 buckets with your subscription. To use the services of the SRT and make an AssociateDRTLogBucket request, you must be subscribed to the Business Support plan or the Enterprise Support plan.

    Args:
        log_bucket(str): The Amazon S3 bucket that contains the logs that you want to share.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.drt.log_bucket.associate(ctx, log_bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.drt.log_bucket.associate log_bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="associate_drt_log_bucket",
        op_kwargs={"LogBucket": log_bucket},
    )


async def disassociate(hub, ctx, log_bucket: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the Shield Response Team's (SRT) access to the specified Amazon S3 bucket containing the logs that you shared previously. To make a DisassociateDRTLogBucket request, you must be subscribed to the Business Support plan or the Enterprise Support plan. However, if you are not subscribed to one of these support plans, but had been previously and had granted the SRT access to your account, you can submit a DisassociateDRTLogBucket request to remove this access.

    Args:
        log_bucket(str): The Amazon S3 bucket that contains the logs that you want to share.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.drt.log_bucket.disassociate(ctx, log_bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.drt.log_bucket.disassociate log_bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="disassociate_drt_log_bucket",
        op_kwargs={"LogBucket": log_bucket},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, launch_profile_id: str, studio_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Launch profile details include the launch profile resource and summary information of resources that are used by, or available to, the launch profile. This includes the name and description of all studio components used by the launch profiles, and the name and description of streaming images that can be used with this launch profile.

    Args:
        launch_profile_id(str): The launch profile ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.launch_profile.detail.get_all(
                ctx, launch_profile_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.launch_profile.detail.get_all launch_profile_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="get_launch_profile_details",
        op_kwargs={"launchProfileId": launch_profile_id, "studioId": studio_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, backup_plan_template_json: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a valid JSON document specifying a backup plan or an error.

    Args:
        backup_plan_template_json(str): A customer-supplied backup plan document in JSON format.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.plan.from_.json.get(
                ctx, backup_plan_template_json=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.plan.from_.json.get backup_plan_template_json=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="get_backup_plan_from_json",
        op_kwargs={"BackupPlanTemplateJson": backup_plan_template_json},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, tags: List, resource_id: str, resource_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to an object, up to a limit of 10. Each tag consists of a key and an optional value. If you add a tag using a key that is already associated with the ML object, AddTags updates the tag's value.

    Args:
        tags(List): The key-value pairs to use to create tags. If you specify a key without specifying a value, Amazon ML creates a tag with the specified key and a value of null.
        resource_id(str): The ID of the ML object to tag. For example, exampleModelId.
        resource_type(str): The type of the ML object to tag.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.tags.add(
                ctx, tags=value, resource_id=value, resource_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.tags.add tags=value, resource_id=value, resource_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="add_tags",
        op_kwargs={
            "Tags": tags,
            "ResourceId": resource_id,
            "ResourceType": resource_type,
        },
    )


async def delete(
    hub, ctx, tag_keys: List, resource_id: str, resource_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified tags associated with an ML object. After this operation is complete, you can't recover deleted tags. If you specify a tag that doesn't exist, Amazon ML ignores it.

    Args:
        tag_keys(List): One or more tags to delete.
        resource_id(str): The ID of the tagged ML object. For example, exampleModelId.
        resource_type(str): The type of the tagged ML object.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.tags.delete(
                ctx, tag_keys=value, resource_id=value, resource_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.tags.delete tag_keys=value, resource_id=value, resource_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="delete_tags",
        op_kwargs={
            "TagKeys": tag_keys,
            "ResourceId": resource_id,
            "ResourceType": resource_type,
        },
    )


async def describe(hub, ctx, resource_id: str, resource_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of the tags for your Amazon ML object.

    Args:
        resource_id(str): The ID of the ML object. For example, exampleModelId. .
        resource_type(str): The type of the ML object.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.tags.describe(
                ctx, resource_id=value, resource_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.tags.describe resource_id=value, resource_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="describe_tags",
        op_kwargs={"ResourceId": resource_id, "ResourceType": resource_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, backup_vault_name: str, recovery_point_arn: str, lifecycle: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the transition lifecycle of a recovery point. The lifecycle defines when a protected resource is transitioned to cold storage and when it expires. AWS Backup transitions and expires backups automatically according to the lifecycle that you define. Backups transitioned to cold storage must be stored in cold storage for a minimum of 90 days. Therefore, the “expire after days” setting must be 90 days greater than the “transition to cold after days” setting. The “transition to cold after days” setting cannot be changed after a backup has been transitioned to cold. Only Amazon EFS file system backups can be transitioned to cold storage. Does not support continuous backups.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.
        recovery_point_arn(str): An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
        lifecycle(Dict, optional): The lifecycle defines when a protected resource is transitioned to cold storage and when it expires. AWS Backup transitions and expires backups automatically according to the lifecycle that you define.  Backups transitioned to cold storage must be stored in cold storage for a minimum of 90 days. Therefore, the “expire after days” setting must be 90 days greater than the “transition to cold after days” setting. The “transition to cold after days” setting cannot be changed after a backup has been transitioned to cold. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.recovery_point.lifecycle.update(
                ctx, backup_vault_name=value, recovery_point_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.recovery_point.lifecycle.update backup_vault_name=value, recovery_point_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="update_recovery_point_lifecycle",
        op_kwargs={
            "BackupVaultName": backup_vault_name,
            "RecoveryPointArn": recovery_point_arn,
            "Lifecycle": lifecycle,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    asset_id: str,
    hierarchy_id: str,
    child_asset_id: str,
    client_token: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Associates a child asset with the given parent asset through a hierarchy defined in the parent asset's model. For more information, see Associating assets in the IoT SiteWise User Guide.

    Args:
        asset_id(str): The ID of the parent asset.
        hierarchy_id(str): The ID of a hierarchy in the parent asset's model. Hierarchies allow different groupings of assets to be formed that all come from the same asset model. For more information, see Asset hierarchies in the IoT SiteWise User Guide.
        child_asset_id(str): The ID of the child asset to be associated.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.init.associate(
                ctx, asset_id=value, hierarchy_id=value, child_asset_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.init.associate asset_id=value, hierarchy_id=value, child_asset_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="associate_assets",
        op_kwargs={
            "assetId": asset_id,
            "hierarchyId": hierarchy_id,
            "childAssetId": child_asset_id,
            "clientToken": client_token,
        },
    )


async def create(
    hub,
    ctx,
    asset_name: str,
    asset_model_id: str,
    client_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an asset from an existing asset model. For more information, see Creating assets in the IoT SiteWise User Guide.

    Args:
        asset_name(str): A unique, friendly name for the asset.
        asset_model_id(str): The ID of the asset model from which to create the asset.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.
        tags(Dict, optional): A list of key-value pairs that contain metadata for the asset. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.init.create(
                ctx, asset_name=value, asset_model_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.init.create asset_name=value, asset_model_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="create_asset",
        op_kwargs={
            "assetName": asset_name,
            "assetModelId": asset_model_id,
            "clientToken": client_token,
            "tags": tags,
        },
    )


async def delete(hub, ctx, asset_id: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an asset. This action can't be undone. For more information, see Deleting assets and models in the IoT SiteWise User Guide.   You can't delete an asset that's associated to another asset. For more information, see DisassociateAssets.

    Args:
        asset_id(str): The ID of the asset to delete.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.init.delete(ctx, asset_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.init.delete asset_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="delete_asset",
        op_kwargs={"assetId": asset_id, "clientToken": client_token},
    )


async def describe(hub, ctx, asset_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an asset.

    Args:
        asset_id(str): The ID of the asset.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.init.describe(ctx, asset_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.init.describe asset_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="describe_asset",
        op_kwargs={"assetId": asset_id},
    )


async def disassociate(
    hub,
    ctx,
    asset_id: str,
    hierarchy_id: str,
    child_asset_id: str,
    client_token: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Disassociates a child asset from the given parent asset through a hierarchy defined in the parent asset's model.

    Args:
        asset_id(str): The ID of the parent asset from which to disassociate the child asset.
        hierarchy_id(str): The ID of a hierarchy in the parent asset's model. Hierarchies allow different groupings of assets to be formed that all come from the same asset model. You can use the hierarchy ID to identify the correct asset to disassociate. For more information, see Asset hierarchies in the IoT SiteWise User Guide.
        child_asset_id(str): The ID of the child asset to disassociate.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.init.disassociate(
                ctx, asset_id=value, hierarchy_id=value, child_asset_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.init.disassociate asset_id=value, hierarchy_id=value, child_asset_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="disassociate_assets",
        op_kwargs={
            "assetId": asset_id,
            "hierarchyId": hierarchy_id,
            "childAssetId": child_asset_id,
            "clientToken": client_token,
        },
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    asset_model_id: str = None,
    filter_: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a paginated list of asset summaries. You can use this operation to do the following:   List assets based on a specific asset model.   List top-level assets.   You can't use this operation to list all assets. To retrieve summaries for all of your assets, use ListAssetModels to get all of your asset model IDs. Then, use ListAssets to get all assets for each asset model.

    Args:
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for each paginated request. Default: 50. Defaults to None.
        asset_model_id(str, optional): The ID of the asset model by which to filter the list of assets. This parameter is required if you choose ALL for filter. Defaults to None.
        filter_(str, optional): The filter for the requested list of assets. Choose one of the following options:    ALL – The list includes all assets for a given asset model ID. The assetModelId parameter is required if you filter by ALL.    TOP_LEVEL – The list includes only top-level assets in the asset hierarchy tree.   Default: ALL . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="list_assets",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "assetModelId": asset_model_id,
            "filter": filter_,
        },
    )


async def update(
    hub, ctx, asset_id: str, asset_name: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an asset's name. For more information, see Updating assets and models in the IoT SiteWise User Guide.

    Args:
        asset_id(str): The ID of the asset to update.
        asset_name(str): A unique, friendly name for the asset.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.init.update(
                ctx, asset_id=value, asset_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.init.update asset_id=value, asset_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="update_asset",
        op_kwargs={
            "assetId": asset_id,
            "assetName": asset_name,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, trace_ids: List, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a service graph for one or more specific trace IDs.

    Args:
        trace_ids(List): Trace IDs of requests for which to generate a service graph.
        next_token(str, optional): Pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.trace.graph.get(ctx, trace_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.trace.graph.get trace_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_trace_graph",
        op_kwargs={"TraceIds": trace_ids, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Assigns one or more tags (key-value pairs) to the specified CloudWatch resource. Currently, the only CloudWatch resources that can be tagged are alarms and Contributor Insights rules. Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values. Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters. You can use the TagResource action with an alarm that already has tags. If you specify a new tag key for the alarm, this tag is appended to the list of tags associated with the alarm. If you specify a tag key that is already associated with the alarm, the new tag value that you specify replaces the previous value for that tag. You can associate as many as 50 tags with a CloudWatch resource.

    Args:
        resource_arn(str): The ARN of the CloudWatch resource that you're adding tags to. The ARN format of an alarm is arn:aws:cloudwatch:Region:account-id:alarm:alarm-name   The ARN format of a Contributor Insights rule is arn:aws:cloudwatch:Region:account-id:insight-rule:insight-rule-name   For more information about ARN format, see  Resource Types Defined by Amazon CloudWatch in the Amazon Web Services General Reference.
        tags(List): The list of key-value pairs to associate with the alarm.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from the specified resource.

    Args:
        resource_arn(str): The ARN of the CloudWatch resource that you're removing tags from. The ARN format of an alarm is arn:aws:cloudwatch:Region:account-id:alarm:alarm-name   The ARN format of a Contributor Insights rule is arn:aws:cloudwatch:Region:account-id:insight-rule:insight-rule-name   For more information about ARN format, see  Resource Types Defined by Amazon CloudWatch in the Amazon Web Services General Reference.
        tag_keys(List): The list of tag keys to remove from the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    application_id: str,
    configuration_profile_id: str,
    content: bytes,
    content_type: str,
    description: str = None,
    latest_version_number: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new configuration in the AppConfig configuration store.

    Args:
        application_id(str): The application ID.
        configuration_profile_id(str): The configuration profile ID.
        description(str, optional): A description of the configuration. Defaults to None.
        content(bytes): The content of the configuration or the configuration data.
        content_type(str): A standard MIME type describing the format of the configuration content. For more information, see Content-Type.
        latest_version_number(int, optional): An optional locking token used to prevent race conditions from overwriting configuration updates when creating a new version. To ensure your data is not overwritten when creating multiple hosted configuration versions in rapid succession, specify the version of the latest hosted configuration version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.hosted_configuration_version.create(
                ctx,
                application_id=value,
                configuration_profile_id=value,
                content=value,
                content_type=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.hosted_configuration_version.create application_id=value, configuration_profile_id=value, content=value, content_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="create_hosted_configuration_version",
        op_kwargs={
            "ApplicationId": application_id,
            "ConfigurationProfileId": configuration_profile_id,
            "Description": description,
            "Content": content,
            "ContentType": content_type,
            "LatestVersionNumber": latest_version_number,
        },
    )


async def delete(
    hub, ctx, application_id: str, configuration_profile_id: str, version_number: int
) -> None:
    r"""
    **Autogenerated function**

    Delete a version of a configuration from the AppConfig configuration store.

    Args:
        application_id(str): The application ID.
        configuration_profile_id(str): The configuration profile ID.
        version_number(int): The versions number to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.hosted_configuration_version.delete(
                ctx, application_id=value, configuration_profile_id=value, version_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.hosted_configuration_version.delete application_id=value, configuration_profile_id=value, version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="delete_hosted_configuration_version",
        op_kwargs={
            "ApplicationId": application_id,
            "ConfigurationProfileId": configuration_profile_id,
            "VersionNumber": version_number,
        },
    )


async def get(
    hub, ctx, application_id: str, configuration_profile_id: str, version_number: int
) -> Dict:
    r"""
    **Autogenerated function**

    Get information about a specific configuration version.

    Args:
        application_id(str): The application ID.
        configuration_profile_id(str): The configuration profile ID.
        version_number(int): The version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.hosted_configuration_version.get(
                ctx, application_id=value, configuration_profile_id=value, version_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.hosted_configuration_version.get application_id=value, configuration_profile_id=value, version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="get_hosted_configuration_version",
        op_kwargs={
            "ApplicationId": application_id,
            "ConfigurationProfileId": configuration_profile_id,
            "VersionNumber": version_number,
        },
    )


async def list_all(
    hub,
    ctx,
    application_id: str,
    configuration_profile_id: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    View a list of configurations stored in the AppConfig configuration store by version.

    Args:
        application_id(str): The application ID.
        configuration_profile_id(str): The configuration profile ID.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.hosted_configuration_version.list_all(
                ctx, application_id=value, configuration_profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.hosted_configuration_version.list_all application_id=value, configuration_profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="list_hosted_configuration_versions",
        op_kwargs={
            "ApplicationId": application_id,
            "ConfigurationProfileId": configuration_profile_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(hub, ctx, configuration_set_name: str, enabled: bool) -> None:
    r"""
    **Autogenerated function**

    Enables or disables email sending for messages sent using a specific configuration set in a given AWS Region. You can use this operation in conjunction with Amazon CloudWatch alarms to temporarily pause email sending for a configuration set when the reputation metrics for that configuration set (such as your bounce on complaint rate) exceed certain thresholds. You can execute this operation no more than once per second.

    Args:
        configuration_set_name(str): The name of the configuration set that you want to update.
        enabled(bool): Describes whether email sending is enabled or disabled for the configuration set. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.sending_enabled.update(
                ctx, configuration_set_name=value, enabled=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.sending_enabled.update configuration_set_name=value, enabled=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="update_configuration_set_sending_enabled",
        op_kwargs={"ConfigurationSetName": configuration_set_name, "Enabled": enabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Lists the Availability Zones that have available AWS CloudHSM capacity.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.available_zone.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.available_zone.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="cloudhsm", operation="list_available_zones", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    subscription_name: str,
    sns_topic_arn: str,
    source_type: str = None,
    event_categories: List = None,
    source_ids: List = None,
    enabled: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon DocumentDB event notification subscription. This action requires a topic Amazon Resource Name (ARN) created by using the Amazon DocumentDB console, the Amazon SNS console, or the Amazon SNS API. To obtain an ARN with Amazon SNS, you must create a topic in Amazon SNS and subscribe to the topic. The ARN is displayed in the Amazon SNS console. You can specify the type of source (SourceType) that you want to be notified of. You can also provide a list of Amazon DocumentDB sources (SourceIds) that trigger the events, and you can provide a list of event categories (EventCategories) for events that you want to be notified of. For example, you can specify SourceType = db-instance, SourceIds = mydbinstance1, mydbinstance2 and EventCategories = Availability, Backup. If you specify both the SourceType and SourceIds (such as SourceType = db-instance and SourceIdentifier = myDBInstance1), you are notified of all the db-instance events for the specified source. If you specify a SourceType but do not specify a SourceIdentifier, you receive notice of the events for that source type for all your Amazon DocumentDB sources. If you do not specify either the SourceType or the SourceIdentifier, you are notified of events generated from all Amazon DocumentDB sources belonging to your customer account.

    Args:
        subscription_name(str): The name of the subscription. Constraints: The name must be fewer than 255 characters.
        sns_topic_arn(str): The Amazon Resource Name (ARN) of the SNS topic created for event notification. Amazon SNS creates the ARN when you create a topic and subscribe to it.
        source_type(str, optional): The type of source that is generating the events. For example, if you want to be notified of events generated by an instance, you would set this parameter to db-instance. If this value is not specified, all events are returned. Valid values: db-instance, db-cluster, db-parameter-group, db-security-group, db-cluster-snapshot . Defaults to None.
        event_categories(List, optional):  A list of event categories for a SourceType that you want to subscribe to. . Defaults to None.
        source_ids(List, optional): The list of identifiers of the event sources for which events are returned. If not specified, then all sources are included in the response. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can't end with a hyphen or contain two consecutive hyphens. Constraints:   If SourceIds are provided, SourceType must also be provided.   If the source type is an instance, a DBInstanceIdentifier must be provided.   If the source type is a security group, a DBSecurityGroupName must be provided.   If the source type is a parameter group, a DBParameterGroupName must be provided.   If the source type is a snapshot, a DBSnapshotIdentifier must be provided.  . Defaults to None.
        enabled(bool, optional):  A Boolean value; set to true to activate the subscription, set to false to create the subscription but not active it. . Defaults to None.
        tags(List, optional): The tags to be assigned to the event subscription. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.event.subscription.create(
                ctx, subscription_name=value, sns_topic_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.event.subscription.create subscription_name=value, sns_topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="create_event_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SnsTopicArn": sns_topic_arn,
            "SourceType": source_type,
            "EventCategories": event_categories,
            "SourceIds": source_ids,
            "Enabled": enabled,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, subscription_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon DocumentDB event notification subscription.

    Args:
        subscription_name(str): The name of the Amazon DocumentDB event notification subscription that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.event.subscription.delete(ctx, subscription_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.event.subscription.delete subscription_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="delete_event_subscription",
        op_kwargs={"SubscriptionName": subscription_name},
    )


async def describe_all(
    hub,
    ctx,
    subscription_name: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the subscription descriptions for a customer account. The description for a subscription includes SubscriptionName, SNSTopicARN, CustomerID, SourceType, SourceID, CreationTime, and Status. If you specify a SubscriptionName, lists the description for that subscription.

    Args:
        subscription_name(str, optional): The name of the Amazon DocumentDB event notification subscription that you want to describe. Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.event.subscription.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.event.subscription.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="describe_event_subscriptions",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub,
    ctx,
    subscription_name: str,
    sns_topic_arn: str = None,
    source_type: str = None,
    event_categories: List = None,
    enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an existing Amazon DocumentDB event notification subscription.

    Args:
        subscription_name(str): The name of the Amazon DocumentDB event notification subscription.
        sns_topic_arn(str, optional): The Amazon Resource Name (ARN) of the SNS topic created for event notification. The ARN is created by Amazon SNS when you create a topic and subscribe to it. Defaults to None.
        source_type(str, optional): The type of source that is generating the events. For example, if you want to be notified of events generated by an instance, set this parameter to db-instance. If this value is not specified, all events are returned. Valid values: db-instance, db-parameter-group, db-security-group . Defaults to None.
        event_categories(List, optional):  A list of event categories for a SourceType that you want to subscribe to. Defaults to None.
        enabled(bool, optional):  A Boolean value; set to true to activate the subscription. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.event.subscription.modify(ctx, subscription_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.event.subscription.modify subscription_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="modify_event_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SnsTopicArn": sns_topic_arn,
            "SourceType": source_type,
            "EventCategories": event_categories,
            "Enabled": enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    platform_name: str,
    platform_version: str,
    platform_definition_bundle: Dict,
    environment_name: str = None,
    option_settings: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new version of your custom platform.

    Args:
        platform_name(str): The name of your custom platform.
        platform_version(str): The number, such as 1.0.2, for the new platform version.
        platform_definition_bundle(Dict): The location of the platform definition archive in Amazon S3.
        environment_name(str, optional): The name of the builder environment. Defaults to None.
        option_settings(List, optional): The configuration option settings to apply to the builder environment. Defaults to None.
        tags(List, optional): Specifies the tags applied to the new platform version. Elastic Beanstalk applies these tags only to the platform version. Environments that you create using the platform version don't inherit the tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.platform.version.create(
                ctx, platform_name=value, platform_version=value, platform_definition_bundle=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.platform.version.create platform_name=value, platform_version=value, platform_definition_bundle=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="create_platform_version",
        op_kwargs={
            "PlatformName": platform_name,
            "PlatformVersion": platform_version,
            "PlatformDefinitionBundle": platform_definition_bundle,
            "EnvironmentName": environment_name,
            "OptionSettings": option_settings,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, platform_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified version of a custom platform.

    Args:
        platform_arn(str, optional): The ARN of the version of the custom platform. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.platform.version.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.platform.version.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="delete_platform_version",
        op_kwargs={"PlatformArn": platform_arn},
    )


async def describe(hub, ctx, platform_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes a platform version. Provides full details. Compare to ListPlatformVersions, which provides summary information about a list of platform versions. For definitions of platform version and other platform-related terms, see AWS Elastic Beanstalk Platforms Glossary.

    Args:
        platform_arn(str, optional): The ARN of the platform version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.platform.version.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.platform.version.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_platform_version",
        op_kwargs={"PlatformArn": platform_arn},
    )


async def list_all(
    hub, ctx, filters: List = None, max_records: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the platform versions available for your account in an AWS Region. Provides summary information about each platform version. Compare to DescribePlatformVersion, which provides full details about a single platform version. For definitions of platform version and other platform-related terms, see AWS Elastic Beanstalk Platforms Glossary.

    Args:
        filters(List, optional): Criteria for restricting the resulting list of platform versions. The filter is interpreted as a logical conjunction (AND) of the separate PlatformFilter terms. Defaults to None.
        max_records(int, optional): The maximum number of platform version values returned in one call. Defaults to None.
        next_token(str, optional): For a paginated request. Specify a token from a previous response page to retrieve the next response page. All other parameter values must be identical to the ones specified in the initial request. If no NextToken is specified, the first page is retrieved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.platform.version.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.platform.version.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="list_platform_versions",
        op_kwargs={
            "Filters": filters,
            "MaxRecords": max_records,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def change(hub, ctx, queue_url: str, entries: List) -> Dict:
    r"""
    **Autogenerated function**

    Changes the visibility timeout of multiple messages. This is a batch version of  ChangeMessageVisibility. The result of the action on each message is reported individually in the response. You can send up to 10  ChangeMessageVisibility  requests with each ChangeMessageVisibilityBatch action.  Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.  Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:  &AttributeName.1=first   &AttributeName.2=second

    Args:
        queue_url(str): The URL of the Amazon SQS queue whose messages' visibility is changed. Queue URLs and names are case-sensitive.
        entries(List): A list of receipt handles of the messages for which the visibility timeout must be changed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.message.visibility.batch.change(
                ctx, queue_url=value, entries=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.message.visibility.batch.change queue_url=value, entries=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="change_message_visibility_batch",
        op_kwargs={"QueueUrl": queue_url, "Entries": entries},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    function_name: str,
    event_source_arn: str = None,
    enabled: bool = None,
    batch_size: int = None,
    maximum_batching_window_in_seconds: int = None,
    parallelization_factor: int = None,
    starting_position: str = None,
    starting_position_timestamp: str = None,
    destination_config: Dict = None,
    maximum_record_age_in_seconds: int = None,
    bisect_batch_on_function_error: bool = None,
    maximum_retry_attempts: int = None,
    tumbling_window_in_seconds: int = None,
    topics: List = None,
    queues: List = None,
    source_access_configurations: List = None,
    self_managed_event_source: Dict = None,
    function_response_types: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a mapping between an event source and an Lambda function. Lambda reads items from the event source and triggers the function. For details about each event source type, see the following topics. In particular, each of the topics describes the required and optional parameters for the specific event source.      Configuring a Dynamo DB stream as an event source      Configuring a Kinesis stream as an event source      Configuring an SQS queue as an event source      Configuring an MQ broker as an event source      Configuring MSK as an event source      Configuring Self-Managed Apache Kafka as an event source    The following error handling options are only available for stream sources (DynamoDB and Kinesis):    BisectBatchOnFunctionError - If the function returns an error, split the batch in two and retry.    DestinationConfig - Send discarded records to an Amazon SQS queue or Amazon SNS topic.    MaximumRecordAgeInSeconds - Discard records older than the specified age. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires    MaximumRetryAttempts - Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.    ParallelizationFactor - Process multiple batches from each shard concurrently.

    Args:
        event_source_arn(str, optional): The Amazon Resource Name (ARN) of the event source.    Amazon Kinesis - The ARN of the data stream or a stream consumer.    Amazon DynamoDB Streams - The ARN of the stream.    Amazon Simple Queue Service - The ARN of the queue.    Amazon Managed Streaming for Apache Kafka - The ARN of the cluster.  . Defaults to None.
        function_name(str): The name of the Lambda function.  Name formats     Function name - MyFunction.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.    Version or Alias ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction:PROD.    Partial ARN - 123456789012:function:MyFunction.   The length constraint applies only to the full ARN. If you specify only the function name, it's limited to 64 characters in length.
        enabled(bool, optional): If true, the event source mapping is active. Set to false to pause polling and invocation. Defaults to None.
        batch_size(int, optional): The maximum number of items to retrieve in a single batch.    Amazon Kinesis - Default 100. Max 10,000.    Amazon DynamoDB Streams - Default 100. Max 1,000.    Amazon Simple Queue Service - Default 10. For standard queues the max is 10,000. For FIFO queues the max is 10.    Amazon Managed Streaming for Apache Kafka - Default 100. Max 10,000.    Self-Managed Apache Kafka - Default 100. Max 10,000.  . Defaults to None.
        maximum_batching_window_in_seconds(int, optional): (Streams and SQS standard queues) The maximum amount of time to gather records before invoking the function, in seconds. Defaults to None.
        parallelization_factor(int, optional): (Streams only) The number of batches to process from each shard concurrently. Defaults to None.
        starting_position(str, optional): The position in a stream from which to start reading. Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources. AT_TIMESTAMP is only supported for Amazon Kinesis streams. Defaults to None.
        starting_position_timestamp(str, optional): With StartingPosition set to AT_TIMESTAMP, the time from which to start reading. Defaults to None.
        destination_config(Dict, optional): (Streams only) An Amazon SQS queue or Amazon SNS topic destination for discarded records. Defaults to None.
        maximum_record_age_in_seconds(int, optional): (Streams only) Discard records older than the specified age. The default value is infinite (-1). Defaults to None.
        bisect_batch_on_function_error(bool, optional): (Streams only) If the function returns an error, split the batch in two and retry. Defaults to None.
        maximum_retry_attempts(int, optional): (Streams only) Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records will be retried until the record expires. Defaults to None.
        tumbling_window_in_seconds(int, optional): (Streams only) The duration in seconds of a processing window. The range is between 1 second up to 900 seconds. Defaults to None.
        topics(List, optional): The name of the Kafka topic. Defaults to None.
        queues(List, optional):  (MQ) The name of the Amazon MQ broker destination queue to consume. . Defaults to None.
        source_access_configurations(List, optional): An array of authentication protocols or VPC components required to secure your event source. Defaults to None.
        self_managed_event_source(Dict, optional): The Self-Managed Apache Kafka cluster to send records. Defaults to None.
        function_response_types(List, optional): (Streams only) A list of current response type enums applied to the event source mapping. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.event_source_mapping.create(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.event_source_mapping.create function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="create_event_source_mapping",
        op_kwargs={
            "EventSourceArn": event_source_arn,
            "FunctionName": function_name,
            "Enabled": enabled,
            "BatchSize": batch_size,
            "MaximumBatchingWindowInSeconds": maximum_batching_window_in_seconds,
            "ParallelizationFactor": parallelization_factor,
            "StartingPosition": starting_position,
            "StartingPositionTimestamp": starting_position_timestamp,
            "DestinationConfig": destination_config,
            "MaximumRecordAgeInSeconds": maximum_record_age_in_seconds,
            "BisectBatchOnFunctionError": bisect_batch_on_function_error,
            "MaximumRetryAttempts": maximum_retry_attempts,
            "TumblingWindowInSeconds": tumbling_window_in_seconds,
            "Topics": topics,
            "Queues": queues,
            "SourceAccessConfigurations": source_access_configurations,
            "SelfManagedEventSource": self_managed_event_source,
            "FunctionResponseTypes": function_response_types,
        },
    )


async def delete(hub, ctx, uuid: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an event source mapping. You can get the identifier of a mapping from the output of ListEventSourceMappings. When you delete an event source mapping, it enters a Deleting state and might not be completely deleted for several seconds.

    Args:
        uuid(str): The identifier of the event source mapping.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.event_source_mapping.delete(ctx, uuid=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.event_source_mapping.delete uuid=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="delete_event_source_mapping",
        op_kwargs={"UUID": uuid},
    )


async def get(hub, ctx, uuid: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns details about an event source mapping. You can get the identifier of a mapping from the output of ListEventSourceMappings.

    Args:
        uuid(str): The identifier of the event source mapping.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.event_source_mapping.get(ctx, uuid=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.event_source_mapping.get uuid=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_event_source_mapping",
        op_kwargs={"UUID": uuid},
    )


async def list_all(
    hub,
    ctx,
    event_source_arn: str = None,
    function_name: str = None,
    marker: str = None,
    max_items: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists event source mappings. Specify an EventSourceArn to only show event source mappings for a single event source.

    Args:
        event_source_arn(str, optional): The Amazon Resource Name (ARN) of the event source.    Amazon Kinesis - The ARN of the data stream or a stream consumer.    Amazon DynamoDB Streams - The ARN of the stream.    Amazon Simple Queue Service - The ARN of the queue.    Amazon Managed Streaming for Apache Kafka - The ARN of the cluster.  . Defaults to None.
        function_name(str, optional): The name of the Lambda function.  Name formats     Function name - MyFunction.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.    Version or Alias ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction:PROD.    Partial ARN - 123456789012:function:MyFunction.   The length constraint applies only to the full ARN. If you specify only the function name, it's limited to 64 characters in length. Defaults to None.
        marker(str, optional): A pagination token returned by a previous call. Defaults to None.
        max_items(int, optional): The maximum number of event source mappings to return. Note that ListEventSourceMappings returns a maximum of 100 items in each response, even if you set the number higher. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.event_source_mapping.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.event_source_mapping.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="list_event_source_mappings",
        op_kwargs={
            "EventSourceArn": event_source_arn,
            "FunctionName": function_name,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )


async def update(
    hub,
    ctx,
    uuid: str,
    function_name: str = None,
    enabled: bool = None,
    batch_size: int = None,
    maximum_batching_window_in_seconds: int = None,
    destination_config: Dict = None,
    maximum_record_age_in_seconds: int = None,
    bisect_batch_on_function_error: bool = None,
    maximum_retry_attempts: int = None,
    parallelization_factor: int = None,
    source_access_configurations: List = None,
    tumbling_window_in_seconds: int = None,
    function_response_types: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an event source mapping. You can change the function that Lambda invokes, or pause invocation and resume later from the same location. The following error handling options are only available for stream sources (DynamoDB and Kinesis):    BisectBatchOnFunctionError - If the function returns an error, split the batch in two and retry.    DestinationConfig - Send discarded records to an Amazon SQS queue or Amazon SNS topic.    MaximumRecordAgeInSeconds - Discard records older than the specified age. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires    MaximumRetryAttempts - Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.    ParallelizationFactor - Process multiple batches from each shard concurrently.

    Args:
        uuid(str): The identifier of the event source mapping.
        function_name(str, optional): The name of the Lambda function.  Name formats     Function name - MyFunction.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.    Version or Alias ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction:PROD.    Partial ARN - 123456789012:function:MyFunction.   The length constraint applies only to the full ARN. If you specify only the function name, it's limited to 64 characters in length. Defaults to None.
        enabled(bool, optional): If true, the event source mapping is active. Set to false to pause polling and invocation. Defaults to None.
        batch_size(int, optional): The maximum number of items to retrieve in a single batch.    Amazon Kinesis - Default 100. Max 10,000.    Amazon DynamoDB Streams - Default 100. Max 1,000.    Amazon Simple Queue Service - Default 10. For standard queues the max is 10,000. For FIFO queues the max is 10.    Amazon Managed Streaming for Apache Kafka - Default 100. Max 10,000.    Self-Managed Apache Kafka - Default 100. Max 10,000.  . Defaults to None.
        maximum_batching_window_in_seconds(int, optional): (Streams and SQS standard queues) The maximum amount of time to gather records before invoking the function, in seconds. Defaults to None.
        destination_config(Dict, optional): (Streams only) An Amazon SQS queue or Amazon SNS topic destination for discarded records. Defaults to None.
        maximum_record_age_in_seconds(int, optional): (Streams only) Discard records older than the specified age. The default value is infinite (-1). Defaults to None.
        bisect_batch_on_function_error(bool, optional): (Streams only) If the function returns an error, split the batch in two and retry. Defaults to None.
        maximum_retry_attempts(int, optional): (Streams only) Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records will be retried until the record expires. Defaults to None.
        parallelization_factor(int, optional): (Streams only) The number of batches to process from each shard concurrently. Defaults to None.
        source_access_configurations(List, optional): An array of authentication protocols or VPC components required to secure your event source. Defaults to None.
        tumbling_window_in_seconds(int, optional): (Streams only) The duration in seconds of a processing window. The range is between 1 second up to 900 seconds. Defaults to None.
        function_response_types(List, optional): (Streams only) A list of current response type enums applied to the event source mapping. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.event_source_mapping.update(ctx, uuid=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.event_source_mapping.update uuid=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="update_event_source_mapping",
        op_kwargs={
            "UUID": uuid,
            "FunctionName": function_name,
            "Enabled": enabled,
            "BatchSize": batch_size,
            "MaximumBatchingWindowInSeconds": maximum_batching_window_in_seconds,
            "DestinationConfig": destination_config,
            "MaximumRecordAgeInSeconds": maximum_record_age_in_seconds,
            "BisectBatchOnFunctionError": bisect_batch_on_function_error,
            "MaximumRetryAttempts": maximum_retry_attempts,
            "ParallelizationFactor": parallelization_factor,
            "SourceAccessConfigurations": source_access_configurations,
            "TumblingWindowInSeconds": tumbling_window_in_seconds,
            "FunctionResponseTypes": function_response_types,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def recognize(
    hub,
    ctx,
    bot_id: str,
    bot_alias_id: str,
    locale_id: str,
    session_id: str,
    text: str,
    session_state: Dict = None,
    request_attributes: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends user input to Amazon Lex V2. Client applications use this API to send requests to Amazon Lex V2 at runtime. Amazon Lex V2 then interprets the user input using the machine learning model that it build for the bot. In response, Amazon Lex V2 returns the next message to convey to the user and an optional response card to display.

    Args:
        bot_id(str): The identifier of the bot that processes the request.
        bot_alias_id(str): The alias identifier in use for the bot that processes the request.
        locale_id(str): The locale where the session is in use.
        session_id(str): The identifier of the user session that is having the conversation.
        text(str): The text that the user entered. Amazon Lex V2 interprets this text.
        session_state(Dict, optional): The current state of the dialog between the user and the bot. Defaults to None.
        request_attributes(Dict, optional): Request-specific information passed between the client application and Amazon Lex V2  The namespace x-amz-lex: is reserved for special attributes. Don't create any request attributes with the prefix x-amz-lex:. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_runtime.text.recognize(
                ctx, bot_id=value, bot_alias_id=value, locale_id=value, session_id=value, text=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_runtime.text.recognize bot_id=value, bot_alias_id=value, locale_id=value, session_id=value, text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-runtime",
        operation="recognize_text",
        op_kwargs={
            "botId": bot_id,
            "botAliasId": bot_alias_id,
            "localeId": locale_id,
            "sessionId": session_id,
            "text": text,
            "sessionState": session_state,
            "requestAttributes": request_attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, bulk_deployment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the status of a bulk deployment.

    Args:
        bulk_deployment_id(str): The ID of the bulk deployment.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.bulk_deployment.status.get(
                ctx, bulk_deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.bulk_deployment.status.get bulk_deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_bulk_deployment_status",
        op_kwargs={"BulkDeploymentId": bulk_deployment_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    branch_interface_id: str,
    trunk_interface_id: str,
    vlan_id: int = None,
    gre_key: int = None,
    client_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a branch network interface with a trunk network interface. Before you create the association, run the create-network-interface command and set --interface-type to trunk. You must also create a network interface for each branch network interface that you want to associate with the trunk network interface. For more information, see  Network interface trunking in the Amazon Elastic Compute Cloud User Guide.

    Args:
        branch_interface_id(str): The ID of the branch network interface.
        trunk_interface_id(str): The ID of the trunk network interface.
        vlan_id(int, optional): The ID of the VLAN. This applies to the VLAN protocol. Defaults to None.
        gre_key(int, optional): The application key. This applies to the GRE protocol. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.trunk_interface.init.associate(
                ctx, branch_interface_id=value, trunk_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.trunk_interface.init.associate branch_interface_id=value, trunk_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="associate_trunk_interface",
        op_kwargs={
            "BranchInterfaceId": branch_interface_id,
            "TrunkInterfaceId": trunk_interface_id,
            "VlanId": vlan_id,
            "GreKey": gre_key,
            "ClientToken": client_token,
            "DryRun": dry_run,
        },
    )


async def disassociate(
    hub, ctx, association_id: str, client_token: str = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Removes an association between a branch network interface with a trunk network interface.

    Args:
        association_id(str): The ID ofthe association.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.trunk_interface.init.disassociate(ctx, association_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.trunk_interface.init.disassociate association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disassociate_trunk_interface",
        op_kwargs={
            "AssociationId": association_id,
            "ClientToken": client_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    language_code: str,
    base_model_name: str,
    model_name: str,
    input_data_config: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new custom language model. Use Amazon S3 prefixes to provide the location of your input files. The time it takes to create your model depends on the size of your training data.

    Args:
        language_code(str): The language of the input text you're using to train your custom language model.
        base_model_name(str): The Amazon Transcribe standard language model, or base model used to create your custom language model. If you want to use your custom language model to transcribe audio with a sample rate of 16 kHz or greater, choose Wideband. If you want to use your custom language model to transcribe audio with a sample rate that is less than 16 kHz, choose Narrowband.
        model_name(str): The name you choose for your custom language model when you create it.
        input_data_config(Dict): Contains the data access role and the Amazon S3 prefixes to read the required input files to create a custom language model.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.language_model.create(
                ctx,
                language_code=value,
                base_model_name=value,
                model_name=value,
                input_data_config=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.language_model.create language_code=value, base_model_name=value, model_name=value, input_data_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="create_language_model",
        op_kwargs={
            "LanguageCode": language_code,
            "BaseModelName": base_model_name,
            "ModelName": model_name,
            "InputDataConfig": input_data_config,
        },
    )


async def delete(hub, ctx, model_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a custom language model using its name.

    Args:
        model_name(str): The name of the model you're choosing to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.language_model.delete(ctx, model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.language_model.delete model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="delete_language_model",
        op_kwargs={"ModelName": model_name},
    )


async def describe(hub, ctx, model_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a single custom language model. Use this information to see details about the language model in your AWS account. You can also see whether the base language model used to create your custom language model has been updated. If Amazon Transcribe has updated the base model, you can create a new custom language model using the updated base model. If the language model wasn't created, you can use this operation to understand why Amazon Transcribe couldn't create it.

    Args:
        model_name(str): The name of the custom language model you submit to get more information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.language_model.describe(ctx, model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.language_model.describe model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="describe_language_model",
        op_kwargs={"ModelName": model_name},
    )


async def list_all(
    hub,
    ctx,
    status_equals: str = None,
    name_contains: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides more information about the custom language models you've created. You can use the information in this list to find a specific custom language model. You can then use the operation to get more information about it.

    Args:
        status_equals(str, optional): When specified, returns only custom language models with the specified status. Language models are ordered by creation date, with the newest models first. If you don't specify a status, Amazon Transcribe returns all custom language models ordered by date. Defaults to None.
        name_contains(str, optional): When specified, the custom language model names returned contain the substring you've specified. Defaults to None.
        next_token(str, optional): When included, fetches the next set of jobs if the result of the previous request was truncated. Defaults to None.
        max_results(int, optional): The maximum number of language models to return in the response. If there are fewer results in the list, the response contains only the actual results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.language_model.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.language_model.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="list_language_models",
        op_kwargs={
            "StatusEquals": status_equals,
            "NameContains": name_contains,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns information about the bandwidth rate limit schedule of a gateway. By default, gateways do not have bandwidth rate limit schedules, which means no bandwidth rate limiting is in effect. This operation is supported only in the volume and tape gateway types.  This operation returns information about a gateway's bandwidth rate limit schedule. A bandwidth rate limit schedule consists of one or more bandwidth rate limit intervals. A bandwidth rate limit interval defines a period of time on one or more days of the week, during which bandwidth rate limits are specified for uploading, downloading, or both.   A bandwidth rate limit interval consists of one or more days of the week, a start hour and minute, an ending hour and minute, and bandwidth rate limits for uploading and downloading   If no bandwidth rate limit schedule intervals are set for the gateway, this operation returns an empty response. To specify which gateway to describe, use the Amazon Resource Name (ARN) of the gateway in your request.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.bandwidth_rate_limit.schedule.describe(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.bandwidth_rate_limit.schedule.describe gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_bandwidth_rate_limit_schedule",
        op_kwargs={"GatewayARN": gateway_arn},
    )


async def update(
    hub, ctx, gateway_arn: str, bandwidth_rate_limit_intervals: List
) -> Dict:
    r"""
    **Autogenerated function**

     Updates the bandwidth rate limit schedule for a specified gateway. By default, gateways do not have bandwidth rate limit schedules, which means no bandwidth rate limiting is in effect. Use this to initiate or update a gateway's bandwidth rate limit schedule. This operation is supported in the volume and tape gateway types.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        bandwidth_rate_limit_intervals(List):  An array containing bandwidth rate limit schedule intervals for a gateway. When no bandwidth rate limit intervals have been scheduled, the array is empty. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.bandwidth_rate_limit.schedule.update(
                ctx, gateway_arn=value, bandwidth_rate_limit_intervals=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.bandwidth_rate_limit.schedule.update gateway_arn=value, bandwidth_rate_limit_intervals=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_bandwidth_rate_limit_schedule",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "BandwidthRateLimitIntervals": bandwidth_rate_limit_intervals,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the AWS Identity and Access Management (AWS IAM) policy for sharing the specified rule group. You can use the policy to share the rule group using AWS Resource Access Manager (AWS RAM).

    Args:
        arn(str): The ARN (Amazon Resource Name) for the rule group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.policy.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.policy.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_firewall_rule_group_policy",
        op_kwargs={"Arn": arn},
    )


async def put(hub, ctx, arn: str, firewall_rule_group_policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Attaches an AWS Identity and Access Management (AWS IAM) policy for sharing the rule group. You can use the policy to share the rule group using AWS Resource Access Manager (AWS RAM).

    Args:
        arn(str): The ARN (Amazon Resource Name) for the rule group that you want to share.
        firewall_rule_group_policy(str): The AWS Identity and Access Management (AWS IAM) policy to attach to the rule group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.rule.group.policy.put(
                ctx, arn=value, firewall_rule_group_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.rule.group.policy.put arn=value, firewall_rule_group_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="put_firewall_rule_group_policy",
        op_kwargs={"Arn": arn, "FirewallRuleGroupPolicy": firewall_rule_group_policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(
    hub, ctx, conversion_task_id: str, dry_run: bool = None, reason_message: str = None
) -> None:
    r"""
    **Autogenerated function**

    Cancels an active conversion task. The task can be the import of an instance or volume. The action removes all artifacts of the conversion, including a partially uploaded volume or instance. If the conversion is complete or is in the process of transferring the final disk image, the command fails and returns an exception. For more information, see Importing a Virtual Machine Using the Amazon EC2 CLI.

    Args:
        conversion_task_id(str): The ID of the conversion task.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        reason_message(str, optional): The reason for canceling the conversion task. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.conversion_task.cancel(ctx, conversion_task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.conversion_task.cancel conversion_task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="cancel_conversion_task",
        op_kwargs={
            "ConversionTaskId": conversion_task_id,
            "DryRun": dry_run,
            "ReasonMessage": reason_message,
        },
    )


async def describe_all(
    hub, ctx, conversion_task_ids: List = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified conversion tasks or all your conversion tasks. For more information, see the VM Import/Export User Guide. For information about the import manifest referenced by this API action, see VM Import Manifest.

    Args:
        conversion_task_ids(List, optional): The conversion task IDs. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.conversion_task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.conversion_task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_conversion_tasks",
        op_kwargs={"ConversionTaskIds": conversion_task_ids, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    gateway_arn: str,
    vtl_device_ar_ns: List = None,
    marker: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of virtual tape library (VTL) devices for the specified tape gateway. In the response, Storage Gateway returns VTL device information. This operation is only supported in the tape gateway type.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        vtl_device_ar_ns(List, optional): An array of strings, where each string represents the Amazon Resource Name (ARN) of a VTL device.  All of the specified VTL devices must be from the same gateway. If no VTL devices are specified, the result will contain all devices on the specified gateway. . Defaults to None.
        marker(str, optional): An opaque string that indicates the position at which to begin describing the VTL devices. Defaults to None.
        limit(int, optional): Specifies that the number of VTL devices described be limited to the specified number. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.vtl_device.init.describe_all(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.vtl_device.init.describe_all gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_vtl_devices",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "VTLDeviceARNs": vtl_device_ar_ns,
            "Marker": marker,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, cross_account_authorization: str) -> Dict:
    r"""
    **Autogenerated function**

    Create a new cross account readiness authorization.

    Args:
        cross_account_authorization(str): The cross account authorization.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.cross_account_authorization.create(
                ctx, cross_account_authorization=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.cross_account_authorization.create cross_account_authorization=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="create_cross_account_authorization",
        op_kwargs={"CrossAccountAuthorization": cross_account_authorization},
    )


async def delete(hub, ctx, cross_account_authorization: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete cross account readiness authorization

    Args:
        cross_account_authorization(str): The cross account authorization.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.cross_account_authorization.delete(
                ctx, cross_account_authorization=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.cross_account_authorization.delete cross_account_authorization=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="delete_cross_account_authorization",
        op_kwargs={"CrossAccountAuthorization": cross_account_authorization},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a collection of cross account readiness authorizations.

    Args:
        max_results(int, optional): Upper bound on number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_readiness.cross_account_authorization.list_all(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_readiness.cross_account_authorization.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-readiness",
        operation="list_cross_account_authorizations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List all supported Elasticsearch versions

    Args:
        max_results(int, optional):  Set this value to limit the number of results returned. Value provided must be greater than 10 else it wont be honored. . Defaults to None.
        next_token(str, optional):  Paginated APIs accepts NextToken input to returns next page results and provides a NextToken output in the response which can be used by the client to retrieve more results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.elasticsearch.version.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.elasticsearch.version.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="list_elasticsearch_versions",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    filter_by: List = None,
    max_results: int = None,
    next_token: str = None,
    sort_by: Dict = None,
    time_range: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves (queries) quotas and aggregated usage data for one or more accounts.

    Args:
        filter_by(List, optional): An array of objects, one for each condition to use to filter the query results. If you specify more than one condition, Amazon Macie uses an AND operator to join the conditions. Defaults to None.
        max_results(int, optional): The maximum number of items to include in each page of the response. Defaults to None.
        next_token(str, optional): The nextToken string that specifies which page of results to return in a paginated response. Defaults to None.
        sort_by(Dict, optional): The criteria to use to sort the query results. Defaults to None.
        time_range(str, optional): The inclusive time period to query usage data for. Valid values are: MONTH_TO_DATE, for the current calendar month to date; and, PAST_30_DAYS, for the preceding 30 days. If you don't specify a value, Amazon Macie provides usage data for the preceding 30 days. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.usage.statistic.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.usage.statistic.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="get_usage_statistics",
        op_kwargs={
            "filterBy": filter_by,
            "maxResults": max_results,
            "nextToken": next_token,
            "sortBy": sort_by,
            "timeRange": time_range,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(
    hub, ctx, service_namespace: str, resource_id: str, scalable_dimension: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters an Application Auto Scaling scalable target when you have finished using it. To see which resources have been registered, use DescribeScalableTargets.   Deregistering a scalable target deletes the scaling policies and the scheduled actions that are associated with it.

    Args:
        service_namespace(str): The namespace of the AWS service that provides the resource. For a resource provided by your own application or service, use custom-resource instead.
        resource_id(str): The identifier of the resource associated with the scalable target. This string consists of the resource type and unique identifier.   ECS service - The resource type is service and the unique identifier is the cluster name and service name. Example: service/default/sample-webapp.   Spot Fleet request - The resource type is spot-fleet-request and the unique identifier is the Spot Fleet request ID. Example: spot-fleet-request/sfr-73fbd2ce-aa30-494c-8788-1cee4EXAMPLE.   EMR cluster - The resource type is instancegroup and the unique identifier is the cluster ID and instance group ID. Example: instancegroup/j-2EEZNYKUA1NTV/ig-1791Y4E1L8YI0.   AppStream 2.0 fleet - The resource type is fleet and the unique identifier is the fleet name. Example: fleet/sample-fleet.   DynamoDB table - The resource type is table and the unique identifier is the table name. Example: table/my-table.   DynamoDB global secondary index - The resource type is index and the unique identifier is the index name. Example: table/my-table/index/my-table-index.   Aurora DB cluster - The resource type is cluster and the unique identifier is the cluster name. Example: cluster:my-db-cluster.   Amazon SageMaker endpoint variant - The resource type is variant and the unique identifier is the resource ID. Example: endpoint/my-end-point/variant/KMeansClustering.   Custom resources are not supported with a resource type. This parameter must specify the OutputValue from the CloudFormation template stack used to access the resources. The unique identifier is defined by the service provider. More information is available in our GitHub repository.   Amazon Comprehend document classification endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:document-classifier-endpoint/EXAMPLE.   Amazon Comprehend entity recognizer endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:entity-recognizer-endpoint/EXAMPLE.   Lambda provisioned concurrency - The resource type is function and the unique identifier is the function name with a function version or alias name suffix that is not $LATEST. Example: function:my-function:prod or function:my-function:1.   Amazon Keyspaces table - The resource type is table and the unique identifier is the table name. Example: keyspace/mykeyspace/table/mytable.   Amazon MSK cluster - The resource type and unique identifier are specified using the cluster ARN. Example: arn:aws:kafka:us-east-1:123456789012:cluster/demo-cluster-1/6357e0b2-0e6a-4b86-a0b4-70df934c2e31-5.  .
        scalable_dimension(str): The scalable dimension associated with the scalable target. This string consists of the service namespace, resource type, and scaling property.    ecs:service:DesiredCount - The desired task count of an ECS service.    ec2:spot-fleet-request:TargetCapacity - The target capacity of a Spot Fleet request.    elasticmapreduce:instancegroup:InstanceCount - The instance count of an EMR Instance Group.    appstream:fleet:DesiredCapacity - The desired capacity of an AppStream 2.0 fleet.    dynamodb:table:ReadCapacityUnits - The provisioned read capacity for a DynamoDB table.    dynamodb:table:WriteCapacityUnits - The provisioned write capacity for a DynamoDB table.    dynamodb:index:ReadCapacityUnits - The provisioned read capacity for a DynamoDB global secondary index.    dynamodb:index:WriteCapacityUnits - The provisioned write capacity for a DynamoDB global secondary index.    rds:cluster:ReadReplicaCount - The count of Aurora Replicas in an Aurora DB cluster. Available for Aurora MySQL-compatible edition and Aurora PostgreSQL-compatible edition.    sagemaker:variant:DesiredInstanceCount - The number of EC2 instances for an Amazon SageMaker model endpoint variant.    custom-resource:ResourceType:Property - The scalable dimension for a custom resource provided by your own application or service.    comprehend:document-classifier-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend document classification endpoint.    comprehend:entity-recognizer-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend entity recognizer endpoint.    lambda:function:ProvisionedConcurrency - The provisioned concurrency for a Lambda function.    cassandra:table:ReadCapacityUnits - The provisioned read capacity for an Amazon Keyspaces table.    cassandra:table:WriteCapacityUnits - The provisioned write capacity for an Amazon Keyspaces table.    kafka:broker-storage:VolumeSize - The provisioned volume size (in GiB) for brokers in an Amazon MSK cluster.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_autoscaling.scalable_target.deregister(
                ctx, service_namespace=value, resource_id=value, scalable_dimension=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_autoscaling.scalable_target.deregister service_namespace=value, resource_id=value, scalable_dimension=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-autoscaling",
        operation="deregister_scalable_target",
        op_kwargs={
            "ServiceNamespace": service_namespace,
            "ResourceId": resource_id,
            "ScalableDimension": scalable_dimension,
        },
    )


async def describe_all(
    hub,
    ctx,
    service_namespace: str,
    resource_ids: List = None,
    scalable_dimension: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the scalable targets in the specified namespace. You can filter the results using ResourceIds and ScalableDimension.

    Args:
        service_namespace(str): The namespace of the AWS service that provides the resource. For a resource provided by your own application or service, use custom-resource instead.
        resource_ids(List, optional): The identifier of the resource associated with the scalable target. This string consists of the resource type and unique identifier.   ECS service - The resource type is service and the unique identifier is the cluster name and service name. Example: service/default/sample-webapp.   Spot Fleet request - The resource type is spot-fleet-request and the unique identifier is the Spot Fleet request ID. Example: spot-fleet-request/sfr-73fbd2ce-aa30-494c-8788-1cee4EXAMPLE.   EMR cluster - The resource type is instancegroup and the unique identifier is the cluster ID and instance group ID. Example: instancegroup/j-2EEZNYKUA1NTV/ig-1791Y4E1L8YI0.   AppStream 2.0 fleet - The resource type is fleet and the unique identifier is the fleet name. Example: fleet/sample-fleet.   DynamoDB table - The resource type is table and the unique identifier is the table name. Example: table/my-table.   DynamoDB global secondary index - The resource type is index and the unique identifier is the index name. Example: table/my-table/index/my-table-index.   Aurora DB cluster - The resource type is cluster and the unique identifier is the cluster name. Example: cluster:my-db-cluster.   Amazon SageMaker endpoint variant - The resource type is variant and the unique identifier is the resource ID. Example: endpoint/my-end-point/variant/KMeansClustering.   Custom resources are not supported with a resource type. This parameter must specify the OutputValue from the CloudFormation template stack used to access the resources. The unique identifier is defined by the service provider. More information is available in our GitHub repository.   Amazon Comprehend document classification endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:document-classifier-endpoint/EXAMPLE.   Amazon Comprehend entity recognizer endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:entity-recognizer-endpoint/EXAMPLE.   Lambda provisioned concurrency - The resource type is function and the unique identifier is the function name with a function version or alias name suffix that is not $LATEST. Example: function:my-function:prod or function:my-function:1.   Amazon Keyspaces table - The resource type is table and the unique identifier is the table name. Example: keyspace/mykeyspace/table/mytable.   Amazon MSK cluster - The resource type and unique identifier are specified using the cluster ARN. Example: arn:aws:kafka:us-east-1:123456789012:cluster/demo-cluster-1/6357e0b2-0e6a-4b86-a0b4-70df934c2e31-5.  . Defaults to None.
        scalable_dimension(str, optional): The scalable dimension associated with the scalable target. This string consists of the service namespace, resource type, and scaling property. If you specify a scalable dimension, you must also specify a resource ID.    ecs:service:DesiredCount - The desired task count of an ECS service.    ec2:spot-fleet-request:TargetCapacity - The target capacity of a Spot Fleet request.    elasticmapreduce:instancegroup:InstanceCount - The instance count of an EMR Instance Group.    appstream:fleet:DesiredCapacity - The desired capacity of an AppStream 2.0 fleet.    dynamodb:table:ReadCapacityUnits - The provisioned read capacity for a DynamoDB table.    dynamodb:table:WriteCapacityUnits - The provisioned write capacity for a DynamoDB table.    dynamodb:index:ReadCapacityUnits - The provisioned read capacity for a DynamoDB global secondary index.    dynamodb:index:WriteCapacityUnits - The provisioned write capacity for a DynamoDB global secondary index.    rds:cluster:ReadReplicaCount - The count of Aurora Replicas in an Aurora DB cluster. Available for Aurora MySQL-compatible edition and Aurora PostgreSQL-compatible edition.    sagemaker:variant:DesiredInstanceCount - The number of EC2 instances for an Amazon SageMaker model endpoint variant.    custom-resource:ResourceType:Property - The scalable dimension for a custom resource provided by your own application or service.    comprehend:document-classifier-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend document classification endpoint.    comprehend:entity-recognizer-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend entity recognizer endpoint.    lambda:function:ProvisionedConcurrency - The provisioned concurrency for a Lambda function.    cassandra:table:ReadCapacityUnits - The provisioned read capacity for an Amazon Keyspaces table.    cassandra:table:WriteCapacityUnits - The provisioned write capacity for an Amazon Keyspaces table.    kafka:broker-storage:VolumeSize - The provisioned volume size (in GiB) for brokers in an Amazon MSK cluster.  . Defaults to None.
        max_results(int, optional): The maximum number of scalable targets. This value can be between 1 and 50. The default value is 50. If this parameter is used, the operation returns up to MaxResults results at a time, along with a NextToken value. To get the next set of results, include the NextToken value in a subsequent call. If this parameter is not used, the operation returns up to 50 results and a NextToken value, if applicable. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_autoscaling.scalable_target.describe_all(
                ctx, service_namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_autoscaling.scalable_target.describe_all service_namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-autoscaling",
        operation="describe_scalable_targets",
        op_kwargs={
            "ServiceNamespace": service_namespace,
            "ResourceIds": resource_ids,
            "ScalableDimension": scalable_dimension,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def register(
    hub,
    ctx,
    service_namespace: str,
    resource_id: str,
    scalable_dimension: str,
    min_capacity: int = None,
    max_capacity: int = None,
    role_arn: str = None,
    suspended_state: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers or updates a scalable target.  A scalable target is a resource that Application Auto Scaling can scale out and scale in. Scalable targets are uniquely identified by the combination of resource ID, scalable dimension, and namespace.  When you register a new scalable target, you must specify values for minimum and maximum capacity. Current capacity will be adjusted within the specified range when scaling starts. Application Auto Scaling scaling policies will not scale capacity to values that are outside of this range. After you register a scalable target, you do not need to register it again to use other Application Auto Scaling operations. To see which resources have been registered, use DescribeScalableTargets. You can also view the scaling policies for a service namespace by using DescribeScalableTargets. If you no longer need a scalable target, you can deregister it by using DeregisterScalableTarget. To update a scalable target, specify the parameters that you want to change. Include the parameters that identify the scalable target: resource ID, scalable dimension, and namespace. Any parameters that you don't specify are not changed by this update request.

    Args:
        service_namespace(str): The namespace of the AWS service that provides the resource. For a resource provided by your own application or service, use custom-resource instead.
        resource_id(str): The identifier of the resource that is associated with the scalable target. This string consists of the resource type and unique identifier.   ECS service - The resource type is service and the unique identifier is the cluster name and service name. Example: service/default/sample-webapp.   Spot Fleet request - The resource type is spot-fleet-request and the unique identifier is the Spot Fleet request ID. Example: spot-fleet-request/sfr-73fbd2ce-aa30-494c-8788-1cee4EXAMPLE.   EMR cluster - The resource type is instancegroup and the unique identifier is the cluster ID and instance group ID. Example: instancegroup/j-2EEZNYKUA1NTV/ig-1791Y4E1L8YI0.   AppStream 2.0 fleet - The resource type is fleet and the unique identifier is the fleet name. Example: fleet/sample-fleet.   DynamoDB table - The resource type is table and the unique identifier is the table name. Example: table/my-table.   DynamoDB global secondary index - The resource type is index and the unique identifier is the index name. Example: table/my-table/index/my-table-index.   Aurora DB cluster - The resource type is cluster and the unique identifier is the cluster name. Example: cluster:my-db-cluster.   Amazon SageMaker endpoint variant - The resource type is variant and the unique identifier is the resource ID. Example: endpoint/my-end-point/variant/KMeansClustering.   Custom resources are not supported with a resource type. This parameter must specify the OutputValue from the CloudFormation template stack used to access the resources. The unique identifier is defined by the service provider. More information is available in our GitHub repository.   Amazon Comprehend document classification endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:document-classifier-endpoint/EXAMPLE.   Amazon Comprehend entity recognizer endpoint - The resource type and unique identifier are specified using the endpoint ARN. Example: arn:aws:comprehend:us-west-2:123456789012:entity-recognizer-endpoint/EXAMPLE.   Lambda provisioned concurrency - The resource type is function and the unique identifier is the function name with a function version or alias name suffix that is not $LATEST. Example: function:my-function:prod or function:my-function:1.   Amazon Keyspaces table - The resource type is table and the unique identifier is the table name. Example: keyspace/mykeyspace/table/mytable.   Amazon MSK cluster - The resource type and unique identifier are specified using the cluster ARN. Example: arn:aws:kafka:us-east-1:123456789012:cluster/demo-cluster-1/6357e0b2-0e6a-4b86-a0b4-70df934c2e31-5.  .
        scalable_dimension(str): The scalable dimension associated with the scalable target. This string consists of the service namespace, resource type, and scaling property.    ecs:service:DesiredCount - The desired task count of an ECS service.    ec2:spot-fleet-request:TargetCapacity - The target capacity of a Spot Fleet request.    elasticmapreduce:instancegroup:InstanceCount - The instance count of an EMR Instance Group.    appstream:fleet:DesiredCapacity - The desired capacity of an AppStream 2.0 fleet.    dynamodb:table:ReadCapacityUnits - The provisioned read capacity for a DynamoDB table.    dynamodb:table:WriteCapacityUnits - The provisioned write capacity for a DynamoDB table.    dynamodb:index:ReadCapacityUnits - The provisioned read capacity for a DynamoDB global secondary index.    dynamodb:index:WriteCapacityUnits - The provisioned write capacity for a DynamoDB global secondary index.    rds:cluster:ReadReplicaCount - The count of Aurora Replicas in an Aurora DB cluster. Available for Aurora MySQL-compatible edition and Aurora PostgreSQL-compatible edition.    sagemaker:variant:DesiredInstanceCount - The number of EC2 instances for an Amazon SageMaker model endpoint variant.    custom-resource:ResourceType:Property - The scalable dimension for a custom resource provided by your own application or service.    comprehend:document-classifier-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend document classification endpoint.    comprehend:entity-recognizer-endpoint:DesiredInferenceUnits - The number of inference units for an Amazon Comprehend entity recognizer endpoint.    lambda:function:ProvisionedConcurrency - The provisioned concurrency for a Lambda function.    cassandra:table:ReadCapacityUnits - The provisioned read capacity for an Amazon Keyspaces table.    cassandra:table:WriteCapacityUnits - The provisioned write capacity for an Amazon Keyspaces table.    kafka:broker-storage:VolumeSize - The provisioned volume size (in GiB) for brokers in an Amazon MSK cluster.  .
        min_capacity(int, optional): The minimum value that you plan to scale in to. When a scaling policy is in effect, Application Auto Scaling can scale in (contract) as needed to the minimum capacity limit in response to changing demand. This property is required when registering a new scalable target. For certain resources, the minimum value allowed is 0. This includes Lambda provisioned concurrency, Spot Fleet, ECS services, Aurora DB clusters, EMR clusters, and custom resources. For all other resources, the minimum value allowed is 1. Defaults to None.
        max_capacity(int, optional): The maximum value that you plan to scale out to. When a scaling policy is in effect, Application Auto Scaling can scale out (expand) as needed to the maximum capacity limit in response to changing demand. This property is required when registering a new scalable target. Although you can specify a large maximum capacity, note that service quotas may impose lower limits. Each service has its own default quotas for the maximum capacity of the resource. If you want to specify a higher limit, you can request an increase. For more information, consult the documentation for that service. For information about the default quotas for each service, see Service Endpoints and Quotas in the Amazon Web Services General Reference. Defaults to None.
        role_arn(str, optional): This parameter is required for services that do not support service-linked roles (such as Amazon EMR), and it must specify the ARN of an IAM role that allows Application Auto Scaling to modify the scalable target on your behalf.  If the service supports service-linked roles, Application Auto Scaling uses a service-linked role, which it creates if it does not yet exist. For more information, see Application Auto Scaling IAM roles. Defaults to None.
        suspended_state(Dict, optional): An embedded object that contains attributes and attribute values that are used to suspend and resume automatic scaling. Setting the value of an attribute to true suspends the specified scaling activities. Setting it to false (default) resumes the specified scaling activities.   Suspension Outcomes    For DynamicScalingInSuspended, while a suspension is in effect, all scale-in activities that are triggered by a scaling policy are suspended.   For DynamicScalingOutSuspended, while a suspension is in effect, all scale-out activities that are triggered by a scaling policy are suspended.   For ScheduledScalingSuspended, while a suspension is in effect, all scaling activities that involve scheduled actions are suspended.    For more information, see Suspending and resuming scaling in the Application Auto Scaling User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_autoscaling.scalable_target.register(
                ctx, service_namespace=value, resource_id=value, scalable_dimension=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_autoscaling.scalable_target.register service_namespace=value, resource_id=value, scalable_dimension=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-autoscaling",
        operation="register_scalable_target",
        op_kwargs={
            "ServiceNamespace": service_namespace,
            "ResourceId": resource_id,
            "ScalableDimension": scalable_dimension,
            "MinCapacity": min_capacity,
            "MaxCapacity": max_capacity,
            "RoleARN": role_arn,
            "SuspendedState": suspended_state,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def export(
    hub,
    ctx,
    s3_destination_config: Dict,
    account_ids: List = None,
    filters: List = None,
    fields_to_export: List = None,
    file_format: str = None,
    include_member_accounts: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Exports optimization recommendations for AWS Lambda functions. Recommendations are exported in a comma-separated values (.csv) file, and its metadata in a JavaScript Object Notation (.json) file, to an existing Amazon Simple Storage Service (Amazon S3) bucket that you specify. For more information, see Exporting Recommendations in the Compute Optimizer User Guide. You can have only one Lambda function export job in progress per AWS Region.

    Args:
        account_ids(List, optional): The IDs of the AWS accounts for which to export Lambda function recommendations. If your account is the management account of an organization, use this parameter to specify the member account for which you want to export recommendations. This parameter cannot be specified together with the include member accounts parameter. The parameters are mutually exclusive. Recommendations for member accounts are not included in the export if this parameter, or the include member accounts parameter, is omitted. You can specify multiple account IDs per request. Defaults to None.
        filters(List, optional): An array of objects that describe a filter to export a more specific set of Lambda function recommendations. Defaults to None.
        fields_to_export(List, optional): The recommendations data to include in the export file. For more information about the fields that can be exported, see Exported files in the Compute Optimizer User Guide. Defaults to None.
        s3_destination_config(Dict): Describes the destination Amazon Simple Storage Service (Amazon S3) bucket name and key prefix for a recommendations export job. You must create the destination Amazon S3 bucket for your recommendations export before you create the export job. Compute Optimizer does not create the S3 bucket for you. After you create the S3 bucket, ensure that it has the required permission policy to allow Compute Optimizer to write the export file to it. If you plan to specify an object prefix when you create the export job, you must include the object prefix in the policy that you add to the S3 bucket. For more information, see Amazon S3 Bucket Policy for Compute Optimizer in the Compute Optimizer user guide.
        file_format(str, optional): The format of the export file. The only export file format currently supported is Csv. Defaults to None.
        include_member_accounts(bool, optional): Indicates whether to include recommendations for resources in all member accounts of the organization if your account is the management account of an organization. The member accounts must also be opted in to Compute Optimizer, and trusted access for Compute Optimizer must be enabled in the organization account. For more information, see Compute Optimizer and AWS Organizations trusted access in the AWS Compute Optimizer User Guide. Recommendations for member accounts of the organization are not included in the export file if this parameter is omitted. This parameter cannot be specified together with the account IDs parameter. The parameters are mutually exclusive. Recommendations for member accounts are not included in the export if this parameter, or the account IDs parameter, is omitted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.compute_optimizer.lambda_function_recommendation.export(
                ctx, s3_destination_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.compute_optimizer.lambda_function_recommendation.export s3_destination_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="compute-optimizer",
        operation="export_lambda_function_recommendations",
        op_kwargs={
            "accountIds": account_ids,
            "filters": filters,
            "fieldsToExport": fields_to_export,
            "s3DestinationConfig": s3_destination_config,
            "fileFormat": file_format,
            "includeMemberAccounts": include_member_accounts,
        },
    )


async def get_all(
    hub,
    ctx,
    function_arns: List = None,
    account_ids: List = None,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns AWS Lambda function recommendations. AWS Compute Optimizer generates recommendations for functions that meet a specific set of requirements. For more information, see the Supported resources and requirements in the AWS Compute Optimizer User Guide.

    Args:
        function_arns(List, optional): The Amazon Resource Name (ARN) of the functions for which to return recommendations. You can specify a qualified or unqualified ARN. If you specify an unqualified ARN without a function version suffix, Compute Optimizer will return recommendations for the latest ($LATEST) version of the function. If you specify a qualified ARN with a version suffix, Compute Optimizer will return recommendations for the specified function version. For more information about using function versions, see Using versions in the AWS Lambda Developer Guide. Defaults to None.
        account_ids(List, optional): The ID of the AWS account for which to return function recommendations. If your account is the management account of an organization, use this parameter to specify the member account for which you want to return function recommendations. Only one account ID can be specified per request. Defaults to None.
        filters(List, optional): An array of objects that describe a filter that returns a more specific list of function recommendations. Defaults to None.
        next_token(str, optional): The token to advance to the next page of function recommendations. Defaults to None.
        max_results(int, optional): The maximum number of function recommendations to return with a single request. To retrieve the remaining results, make another request with the returned NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.compute_optimizer.lambda_function_recommendation.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.compute_optimizer.lambda_function_recommendation.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="compute-optimizer",
        operation="get_lambda_function_recommendations",
        op_kwargs={
            "functionArns": function_arns,
            "accountIds": account_ids,
            "filters": filters,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def abort(hub, ctx, account_id: str, vault_name: str, upload_id: str) -> None:
    r"""
    **Autogenerated function**

    This operation aborts a multipart upload identified by the upload ID. After the Abort Multipart Upload request succeeds, you cannot upload any more parts to the multipart upload or complete the multipart upload. Aborting a completed upload fails. However, aborting an already-aborted upload will succeed, for a short time. For more information about uploading a part and completing a multipart upload, see UploadMultipartPart and CompleteMultipartUpload. This operation is idempotent. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM).  For conceptual information and underlying REST API, see Working with Archives in Amazon S3 Glacier and Abort Multipart Upload in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        upload_id(str): The upload ID of the multipart upload to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.multipart.upload.abort(
                ctx, account_id=value, vault_name=value, upload_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.multipart.upload.abort account_id=value, vault_name=value, upload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="abort_multipart_upload",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "uploadId": upload_id,
        },
    )


async def complete(
    hub,
    ctx,
    account_id: str,
    vault_name: str,
    upload_id: str,
    archive_size: str = None,
    checksum: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    You call this operation to inform Amazon S3 Glacier (Glacier) that all the archive parts have been uploaded and that Glacier can now assemble the archive from the uploaded parts. After assembling and saving the archive to the vault, Glacier returns the URI path of the newly created archive resource. Using the URI path, you can then access the archive. After you upload an archive, you should save the archive ID returned to retrieve the archive at a later point. You can also get the vault inventory to obtain a list of archive IDs in a vault. For more information, see InitiateJob. In the request, you must include the computed SHA256 tree hash of the entire archive you have uploaded. For information about computing a SHA256 tree hash, see Computing Checksums. On the server side, Glacier also constructs the SHA256 tree hash of the assembled archive. If the values match, Glacier saves the archive to the vault; otherwise, it returns an error, and the operation fails. The ListParts operation returns a list of parts uploaded for a specific multipart upload. It includes checksum information for each uploaded part that can be used to debug a bad checksum issue. Additionally, Glacier also checks for any missing content ranges when assembling the archive, if missing content ranges are found, Glacier returns an error and the operation fails. Complete Multipart Upload is an idempotent operation. After your first successful complete multipart upload, if you call the operation again within a short period, the operation will succeed and return the same archive ID. This is useful in the event you experience a network issue that causes an aborted connection or receive a 500 server error, in which case you can repeat your Complete Multipart Upload request and get the same archive ID without creating duplicate archives. Note, however, that after the multipart upload completes, you cannot call the List Parts operation and the multipart upload will not appear in List Multipart Uploads response, even if idempotent complete is possible. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM).  For conceptual information and underlying REST API, see Uploading Large Archives in Parts (Multipart Upload) and Complete Multipart Upload in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        upload_id(str): The upload ID of the multipart upload.
        archive_size(str, optional): The total size, in bytes, of the entire archive. This value should be the sum of all the sizes of the individual parts that you uploaded. Defaults to None.
        checksum(str, optional): The SHA256 tree hash of the entire archive. It is the tree hash of SHA256 tree hash of the individual parts. If the value you specify in the request does not match the SHA256 tree hash of the final assembled archive as computed by Amazon S3 Glacier (Glacier), Glacier returns an error and the request fails. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.multipart.upload.complete(
                ctx, account_id=value, vault_name=value, upload_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.multipart.upload.complete account_id=value, vault_name=value, upload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="complete_multipart_upload",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "uploadId": upload_id,
            "archiveSize": archive_size,
            "checksum": checksum,
        },
    )


async def initiate(
    hub,
    ctx,
    account_id: str,
    vault_name: str,
    archive_description: str = None,
    part_size: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation initiates a multipart upload. Amazon S3 Glacier creates a multipart upload resource and returns its ID in the response. The multipart upload ID is used in subsequent requests to upload parts of an archive (see UploadMultipartPart). When you initiate a multipart upload, you specify the part size in number of bytes. The part size must be a megabyte (1024 KB) multiplied by a power of 2-for example, 1048576 (1 MB), 2097152 (2 MB), 4194304 (4 MB), 8388608 (8 MB), and so on. The minimum allowable part size is 1 MB, and the maximum is 4 GB. Every part you upload to this resource (see UploadMultipartPart), except the last one, must have the same size. The last one can be the same size or smaller. For example, suppose you want to upload a 16.2 MB file. If you initiate the multipart upload with a part size of 4 MB, you will upload four parts of 4 MB each and one part of 0.2 MB.   You don't need to know the size of the archive when you start a multipart upload because Amazon S3 Glacier does not require you to specify the overall archive size.  After you complete the multipart upload, Amazon S3 Glacier (Glacier) removes the multipart upload resource referenced by the ID. Glacier also removes the multipart upload resource if you cancel the multipart upload or it may be removed if there is no activity for a period of 24 hours. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM). For conceptual information and underlying REST API, see Uploading Large Archives in Parts (Multipart Upload) and Initiate Multipart Upload in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID. .
        vault_name(str): The name of the vault.
        archive_description(str, optional): The archive description that you are uploading in parts. The part size must be a megabyte (1024 KB) multiplied by a power of 2, for example 1048576 (1 MB), 2097152 (2 MB), 4194304 (4 MB), 8388608 (8 MB), and so on. The minimum allowable part size is 1 MB, and the maximum is 4 GB (4096 MB). Defaults to None.
        part_size(str, optional): The size of each part except the last, in bytes. The last part can be smaller than this part size. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.multipart.upload.initiate(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.multipart.upload.initiate account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="initiate_multipart_upload",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "archiveDescription": archive_description,
            "partSize": part_size,
        },
    )


async def list_all(
    hub, ctx, account_id: str, vault_name: str, marker: str = None, limit: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation lists in-progress multipart uploads for the specified vault. An in-progress multipart upload is a multipart upload that has been initiated by an InitiateMultipartUpload request, but has not yet been completed or aborted. The list returned in the List Multipart Upload response has no guaranteed order.  The List Multipart Uploads operation supports pagination. By default, this operation returns up to 50 multipart uploads in the response. You should always check the response for a marker at which to continue the list; if there are no more items the marker is null. To return a list of multipart uploads that begins at a specific upload, set the marker request parameter to the value you obtained from a previous List Multipart Upload request. You can also limit the number of uploads returned in the response by specifying the limit parameter in the request. Note the difference between this operation and listing parts (ListParts). The List Multipart Uploads operation lists all multipart uploads for a vault and does not require a multipart upload ID. The List Parts operation requires a multipart upload ID since parts are associated with a single upload. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM). For conceptual information and the underlying REST API, see Working with Archives in Amazon S3 Glacier and List Multipart Uploads  in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID. .
        vault_name(str): The name of the vault.
        marker(str, optional): An opaque string used for pagination. This value specifies the upload at which the listing of uploads should begin. Get the marker value from a previous List Uploads response. You need only include the marker if you are continuing the pagination of results started in a previous List Uploads request. Defaults to None.
        limit(str, optional): Specifies the maximum number of uploads returned in the response body. If this value is not specified, the List Uploads operation returns up to 50 uploads. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.multipart.upload.list_all(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.multipart.upload.list_all account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="list_multipart_uploads",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "marker": marker,
            "limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, directory_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Obtains the manual snapshot limits for a directory.

    Args:
        directory_id(str): Contains the identifier of the directory to obtain the limits for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.snapshot.limit.get_all(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.snapshot.limit.get_all directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="get_snapshot_limits",
        op_kwargs={"DirectoryId": directory_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    compatible_environment_templates: List,
    source: Dict,
    template_name: str,
    client_token: str = None,
    description: str = None,
    major_version: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new major or minor version of a service template. A major version of a service template is a version that isn't backwards compatible. A minor version of a service template is a version that's backwards compatible within its major version.

    Args:
        client_token(str, optional): When included, if two identicial requests are made with the same client token, AWS Proton returns the service template version that the first request created. Defaults to None.
        compatible_environment_templates(List): An array of compatible environment template objects for the new version of a service template.
        description(str, optional): A description of the new version of a service template. Defaults to None.
        major_version(str, optional): To create a new minor version of the service template, include a majorVersion. To create a new major and minor version of the service template, exclude majorVersion. Defaults to None.
        source(Dict): An object that includes the template bundle S3 bucket path and name for the new version of a service template.
        tags(List, optional): Create tags for a new version of a service template. Defaults to None.
        template_name(str): The name of the service template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.version.create(
                ctx, compatible_environment_templates=value, source=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.version.create compatible_environment_templates=value, source=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="create_service_template_version",
        op_kwargs={
            "clientToken": client_token,
            "compatibleEnvironmentTemplates": compatible_environment_templates,
            "description": description,
            "majorVersion": major_version,
            "source": source,
            "tags": tags,
            "templateName": template_name,
        },
    )


async def delete(
    hub, ctx, major_version: str, minor_version: str, template_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    If no other minor versions of a service template exist, delete a major version of the service template if it's not the Recommended version. Delete the Recommended version of the service template if no other major versions or minor versions of the service template exist. A major version of a service template is a version that isn't backwards compatible. Delete a minor version of a service template if it's not the Recommended version. Delete a Recommended minor version of the service template if no other minor versions of the service template exist. A minor version of a service template is a version that's backwards compatible.

    Args:
        major_version(str): The service template major version to delete.
        minor_version(str): The service template minor version to delete.
        template_name(str): The name of the service template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.version.delete(
                ctx, major_version=value, minor_version=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.version.delete major_version=value, minor_version=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="delete_service_template_version",
        op_kwargs={
            "majorVersion": major_version,
            "minorVersion": minor_version,
            "templateName": template_name,
        },
    )


async def get(
    hub, ctx, major_version: str, minor_version: str, template_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    View detail data for a major or minor version of a service template.

    Args:
        major_version(str): To view service template major version detail data, include majorVersion.
        minor_version(str): To view service template minor version detail data, include minorVersion.
        template_name(str): The name of the service template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.version.get(
                ctx, major_version=value, minor_version=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.version.get major_version=value, minor_version=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="get_service_template_version",
        op_kwargs={
            "majorVersion": major_version,
            "minorVersion": minor_version,
            "templateName": template_name,
        },
    )


async def list_all(
    hub,
    ctx,
    template_name: str,
    major_version: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List major or minor versions of a service template with detail data.

    Args:
        major_version(str, optional): To view a list of minor of versions under a major version of a service template, include majorVersion. To view a list of major versions of a service template, exclude majorVersion. Defaults to None.
        max_results(int, optional): The maximum number of major or minor versions of a service template to list. Defaults to None.
        next_token(str, optional): A token to indicate the location of the next major or minor version in the array of major or minor versions of a service template, after the list of major or minor versions that was previously requested. Defaults to None.
        template_name(str): The name of the service template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.version.list_all(
                ctx, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.version.list_all template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="list_service_template_versions",
        op_kwargs={
            "majorVersion": major_version,
            "maxResults": max_results,
            "nextToken": next_token,
            "templateName": template_name,
        },
    )


async def update(
    hub,
    ctx,
    major_version: str,
    minor_version: str,
    template_name: str,
    compatible_environment_templates: List = None,
    description: str = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update a major or minor version of a service template.

    Args:
        compatible_environment_templates(List, optional): An array of compatible environment names for a service template major or minor version to update. Defaults to None.
        description(str, optional): A description of a service template version to update. Defaults to None.
        major_version(str): To update a major version of a service template, include majorVersion.
        minor_version(str): To update a minor version of a service template, include minorVersion.
        status(str, optional): The status of the service template minor version to update. Defaults to None.
        template_name(str): The name of the service template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.template.version.update(
                ctx, major_version=value, minor_version=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.template.version.update major_version=value, minor_version=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="update_service_template_version",
        op_kwargs={
            "compatibleEnvironmentTemplates": compatible_environment_templates,
            "description": description,
            "majorVersion": major_version,
            "minorVersion": minor_version,
            "status": status,
            "templateName": template_name,
        },
    )
